# Building Couchbase Python Client

>**NOTE:** This is the documentation for the 4.x version of the client. This is mostly compatible with the older 3.x version. Please refer to the *release32* branch for the older 3.x version.

Document under construction.  Updates coming soon.
